/*****************************************************************
 * FlexControl.cpp
 * 
 * This file contains the code necessary to write an external
 * control module for FlexBot. All code for the FlexControl module
 * can be placed in this file.
 *
 * If placed in the FlexControl directory within the FlexBot directory,
 * this control module will have its ListenForCommands() function
 * called every think cycle. You can send commands back to the game
 * by calling the SendCommand() function defined here. Keep in mind that 
 * calls to this control module are synchronous (blocking), so it is
 * important to make your FlexControl module code efficient so as not to
 * adversely impact game performance.
 *****************************************************************/

#include "stdafx.h"
#include <stdio.h>
#include "FlexControl.h"
#include "SocketServer.h"

// Command listening socket
SocketServer commandSocket(5440);

/*****************************************************
 * LISTEN FOR COMMANDS         					     *
 *													 *
 * This function is called when FlexBot allows the	 *
 * command module to check for external commands.	 *
 * This is where the module should do most of its	 *
 * work.											 *
 *****************************************************/
FLEXCONTROL_API void ListenForCommands(void)
{
	char pattonCmd[1000];		
	if (commandSocket.ReceiveMessage(pattonCmd)) {
		SendCommand(pattonCmd);
	}
}


/*****************************************************
 * DLL MAIN                    					     *
 *													 *
 * This function does NOT need to be modified.       *
 * You may use it to execute initialization code     *
 * for your debugger. It is called when the DLL		 *
 * is initially loaded by FlexBot.                   *
 *****************************************************/
BOOL APIENTRY DllMain( HANDLE hModule, 
                       DWORD  ul_reason_for_call, 
                       LPVOID lpReserved
					 )
{
    switch (ul_reason_for_call)
	{
		case DLL_PROCESS_ATTACH:
		case DLL_THREAD_ATTACH:
		case DLL_THREAD_DETACH:
		case DLL_PROCESS_DETACH:
			break;
    }

	// --- Load pointers to functions exported by FlexBot --- //
	
	// Load the DLL
	char errorMsg[1000];
	initialized = FALSE;
	moduleHandle = FALSE;
	moduleHandle = LoadLibrary("FlexBot/dlls/FlexBot.dll");

	// Could the DLL be loaded?
	if (moduleHandle)
	{
		// Load the function pointer for FLEXCONTROL_SendCommand()
		pfnSendCommand = (PFN_SEND_COMMAND) GetProcAddress(moduleHandle, "FLEXCONTROL_SendCommand");
		if (!pfnSendCommand)
		{
			sprintf(errorMsg, "FlexControl: Error loading function FLEXCONTROL_SendCommand()\n");
			MessageBox(NULL, errorMsg, "FlexControl Error", MB_OK);
			return FALSE;
		}
	}
	else {
		sprintf(errorMsg, "FlexControl: Error loading module \"FlexBot/dlls/FlexBot.dll\"\n");
		MessageBox(NULL, errorMsg, "FlexControl Error", MB_OK);
		return FALSE;
	}

	// Set initialized to true and return success
	initialized = TRUE;
    return TRUE;
}


/*****************************************************
 * SEND COMMAND		         					     *
 *													 *
 * Calling this function will send the specified	 *
 * string to FlexBot for evaluation as a command.	 *
 *****************************************************/
void SendCommand(const char * command) {
	(pfnSendCommand)(command);
}