/*****************************************************************
 * FlexControl.h
 * 
 * This is the header file for the code necessary to write an
 * external control module for the FlexBot MOD in Half-Life. If you
 * are writing a FlexControl module, there is no need to modify this
 * file. All controller-specific code can be placed in the
 * "FlexControl.cpp" file.
 *
 * If placed in the FlexControl directory within the FlexBot directory,
 * this control module will have its ListenForCommands() function
 * called every think cycle. You can send commands back to the game
 * by calling the SendCommand() function defined here. Keep in mind that 
 * calls to this control module are synchronous (blocking), so it is
 * important to make your FlexControl module code efficient so as not to
 * adversely impact game performance.
 *****************************************************************/

#ifdef FLEXCONTROL_EXPORTS
#define FLEXCONTROL_API __declspec(dllexport)
#else
#define FLEXCONTROL_API __declspec(dllimport)
#endif

// Typedef for function pointers to external FlexBot routines
typedef void (* PFN_SEND_COMMAND)(const char *);

// Function pointers to Half-Life
HINSTANCE moduleHandle;
PFN_SEND_COMMAND pfnSendCommand;

// Have the function pointers to FlexBot been loaded yet?
bool initialized = FALSE;

// ------ Exported by this FlexControl module ------ //
FLEXCONTROL_API void ListenForCommands(void);

// ------ Wrapper functions to access FlexBot functions ------ //
void SendCommand(const char *);
